# DABench Task 425 - 1. How many missing values are there in the "max_sust_wind" column?

## Task Description

1. How many missing values are there in the "max_sust_wind" column?

## Concepts

Comprehensive Data Preprocessing

## Data Description

Dataset file: `cost_data_with_errors.csv`

The data is available in the `train.csv` file in the public directory.

## Constraints

Count the number of null values only, do not include non-null values that might be rendered as errors or irrelevant data.

## Files

- `train.csv` - The training data
- `sample_submission.csv` - A sample submission file in the correct format

## Submission Format

Submit a CSV with columns `id,answer`, containing one row. In the `answer` cell include:
@missing_values_count[number]

"number" is an integer representing the count of missing values in the "max_sust_wind" column.

## Evaluation

Submissions are evaluated on **exact match** with the ground truth answer (with tolerance of 0.01 for floating-point values).

## Goal

Provide the correct answer in the specified format.

## Difficulty Level

Easy
